/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

interface DatabaseRes {
  dbType: string
  state: string
  maxConnections: number
  maxUsedConnections: number
  threadsConnections: number
  threadsRunningConnections: number
  date: string
}

type ServerNodeType = 'MASTER' | 'WORKER' | 'ALERT_SERVER'

interface ServerNode {
  id: number
  host: string
  port: number
  zkDirectory: string
  resInfo: string
  createTime: string
  lastHeartbeatTime: string
}

interface MasterNode extends ServerNode {
  serverStatus?: 'NORMAL' | 'BUZY'
}

interface WorkerNode extends ServerNode {
  serverStatus?: 'NORMAL' | 'BUZY'
  workerHostWeight?: number
  threadPoolUsage?: number
}

interface AlertNode extends MasterNode {}

export {
  DatabaseRes,
  MasterNode,
  WorkerNode,
  ServerNodeType,
  ServerNode,
  AlertNode
}
